import matplotlib.pyplot as plt
from skimage import io
from skimage.exposure import match_histograms


def match_images(source_path, reference_path, output_path):
    """
    Carrega duas imagens, faz a correspondência de histograma
    e salva a imagem resultante.
    """
    image = io.imread(source_path)
    reference = io.imread(reference_path)
    matched_image = match_histograms(image, reference, channel_axis=-1)

    io.imsave(output_path, matched_image)

    print(f"Imagem correspondida salva em {output_path}")

    # Opcional: para exibir as imagens no notebook ou script
    fig, (ax1, ax2, ax3) = plt.subplots(
        ncols=3, figsize=(16, 5), sharex=True, sharey=True
    )

    ax1.imshow(image)
    ax1.set_title("Imagem de Origem")

    ax2.imshow(reference)
    ax2.set_title("Imagem de Referência")

    ax3.imshow(matched_image)
    ax3.set_title("Imagem Correspondida")

    plt.tight_layout()
    plt.show()



from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as f:
    page_description = f.read()

with open("requirements.txt", encoding="utf-8") as f:
    requirements = f.read().splitlines()

setup(
    name="package_histmatch",
    version="0.0.1",
    author="Nayara",
    author_email="nayara_franco_almeida@hotmail.com",
    description="My short description",
    long_description=page_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Nayarah/simple-package-template.git",
    packages=find_packages(),
    install_requires=requirements,
    python_requires=">=3.8",
)
